# Business Case

[source 1](http://whatis.techtarget.com/reference/How-to-write-a-business-case)

[source 2](https://resources.workfront.com/project-management-blog/how-to-write-a-business-case-4-steps-to-a-perfect-business-case-template)

## What is a business case?

The business case is developed during the early stages of a project and outlines the __why, how, and who__ necessary to decide if the project is worth continuing. it's first developed during an initial investigation, has much more detail and should be reviewed by the project sponsor and key stakeholders before being accepted, rejected, canceled, deffered, or revised.

BC gives your company the chance to access the following for each project:

* Business problem or opportunity
* Benefits
* Risk
* Costs including investment appraisal
* Likely technical solutions
* Timescale
* Impact on operations
* Organizational capability to deliver the project outcome.

If a project is worth doing you need to answer 5 simple questions:

* What is your goal?
* What's stopping you from reaching the goal?
* How much change is needed to overcome the problem?
* Are you certain this will solve the problem?
* Can you answer these questions quickly? Do you have evidence to support or refute your assumptions?

# How to Write a Business Case

The purpose is communication. Therefore, each section should be written in the parlance of the intended audience. Moreover, it should only contain enough information to help decision making.

As you're writing, keep in mind:

* The document should be brief and convey only the bare essentials
* Make it interesting, clear and concise
* Eliminate conjecture and minimize jargon
* Describe your vision of the future
* Demonstrate the value and benefits to project brings to the Business
* Keep the number of authors to a minimum to ensure consistent style and readability.

# Template

The perfect BC for your project typically includes the following four section:

## Executive Summary

This short summary is the first section of the business case and the last written. It should succinctly convey vital information about the project and communicate the entire story to the reader.

First impression are important. Get this right!

## Finance

This for those who will be approving funding and should include:

1. __A financial appraisal__ - identify the project's financial implications, compare project costs to forecast benefits, ensure every cost is considered, assess value of money, and predict cash flow.
2. __A sensitivity analysis__ - assess project risks, measure the impact of project outcomes or assumptions, and lets project accountants experiment with possible scenarios.

## Project Definition

This is the largest part of the business case and is for the project sponsor, stakeholders, and project team. It should address the following...

### Business Objective

* What is your goal?
* What is needed to overcome the problem?
* How will the project support the business strategy?

### Benefits and Limitations

This section describes the financial and non-financial benefits in turn. The purpose is to explain why you need a project. For instance, to:

* Improve quality
* Save costs through efficiencies
* Reduce working capital - the difference between current assets and current liabilities
* Generate revenue
* Remain competitive
* Improve customer service
* To align to corporate strategy

### Option Identification and Selection

Identify the potential solutions to the problem and describe them in enough detail for the reader to understand.

For instance, if the business case and proposed solution makes use of technology, make sure to explain how the technology is used and define the terms used in a glossary.

The final business case may contain three to five options - the short list - that includes a do nothing or benchmark option.

### Scope, Impact, and interdependencies

This section describes the work needed to deliver the business objective and identifies those business functions affected by the project. it should also state the project's scope and boundaries. It describe what is included and what is excluded plus the key interdependencies with other projects.

Consider the failure of other interrelated projects and show how such dependencies may impact benefits.

### Outline Plan

Ideally, the project should be divided into stages with key decisions preceding each stage. Use this section to answer the following questions:

* What is required?
* How is id done?
* Who does what?
* When will things happen?

This outline plan should also list the major deliverables and include a brief project.

### Market Assessment

Provide a thorough assessment of the business context and make the underlying business interests explicit. Show a complete understanding of the marketplace in which your business operates, considering political, economical, sociological, technological, legal, and environmental factors (or PESTLE, if you like)

### Risk assessment

Summarize the significant risks and opportunities and how they are managed. The risks included should cover those that could arise from you projects or the organization's ability to deliver change, including the following questions:

* What risks are involved?
* What are the consequences of a risk happening?
* What opportunities may emerge?
* What plans are in place to deal with the risks?

### Project Approach

The project approach describes how the project is tackled. That is, the way in which work is done do deliver the project. For instance, a project with much of the work contracted out is likely to take a different approach to a project that develops an in-house solution.

### Purchasing Strategy

This section describes how a project is to be financed and whether a decision to buy, lease, or outsource should be taken by the organization before purchasing.

Moreover, the purchasing strategy should describe the purchasing process used. A formal procurement process may save time and money and reduce project risk.

## Project Organization

The last section is of most interest to the project manager, project team, and managers responsible for delivering work to the project, and should include:

1. __Project governance__ - show how the project is structured and the different levels of decision-making.
2. __Progress reporting__ - define for project progress will be recorded and reported to the project board.
